@@ -1,8 +1,8 @@
 require 'vagrant/action/builder'
-require 'vagrant/action/builtin'
 
 module Vagrant
   module Action
+    autoload :Builtin,     'vagrant/action/builtin'
     autoload :Environment, 'vagrant/action/environment'
     autoload :Runner,      'vagrant/action/runner'
     autoload :Warden,      'vagrant/action/warden'
@@ -20,6 +20,7 @@ module Vagrant
     end
 
     module General
+      autoload :CheckVirtualbox, 'vagrant/action/general/check_virtualbox'
       autoload :Package,  'vagrant/action/general/package'
       autoload :Validate, 'vagrant/action/general/validate'
     end
@@ -35,6 +36,7 @@ module Vagrant
       autoload :ClearNetworkInterfaces, 'vagrant/action/vm/clear_network_interfaces'
       autoload :ClearSharedFolders,  'vagrant/action/vm/clear_shared_folders'
       autoload :Customize,           'vagrant/action/vm/customize'
+      autoload :DefaultName,         'vagrant/action/vm/default_name'
       autoload :Destroy,             'vagrant/action/vm/destroy'
       autoload :DestroyUnusedNetworkInterfaces, 'vagrant/action/vm/destroy_unused_network_interfaces'
       autoload :DiscardState,        'vagrant/action/vm/discard_state'
