@@ -11,7 +11,7 @@ module Vagrant
 
           opts.separator ""
 
-          opts.on("-h", "--host COMMAND", "Name the host for the config..") do |h|
+          opts.on("--host COMMAND", "Name the host for the config..") do |h|
             options[:host] = h
           end
         end
@@ -19,7 +19,7 @@ module Vagrant
         argv = parse_options(opts)
         return if !argv
 
-        with_target_vms(argv[0], true) do |vm|
+        with_target_vms(argv[0], :single_target => true) do |vm|
           raise Errors::VMNotCreatedError if !vm.created?
           raise Errors::VMInaccessible if !vm.state == :inaccessible
 
